==> regina-normal_4.95.orig.tar.gz: regina-4.95/engine/triangulation/nboundarycomponent.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Computational Engine                                                  *
 *                                                                        *
 *  Copyright (c) 1999-2013, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

#include "triangulation/nboundarycomponent.h"

namespace regina {

void NBoundaryComponent::writeTextLong(std::ostream& out) const {
    writeTextShort(out);
    out << std::endl;

    if (isIdeal()) {
        NVertex* v = vertices.front();
        out << "Vertex: " << v->markedIndex() << std::endl;
        out << "Appears as:" << std::endl;
        std::vector<NVertexEmbedding>::const_iterator it;
        for (it = v->getEmbeddings().begin(); it != v->getEmbeddings().end();
                ++it)
            out << "  " << it->getTetrahedron()->markedIndex()
                << " (" << it->getVertex() << ')' << std::endl;
    } else {
        out << "Triangles:" << std::endl;
        std::vector<NTriangle*>::const_iterator it;
        for (it = triangles.begin(); it != triangles.end(); ++it) {
            const NTriangleEmbedding& emb((*it)->getEmbedding(0));
            out << "  " << emb.getTetrahedron()->markedIndex() << " ("
                << emb.getVertices().trunc3() << ')' << std::endl;
        }
    }
}

} // namespace regina

==> regina-normal_4.96.orig.tar.gz: regina-4.96/engine/triangulation/nboundarycomponent.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Computational Engine                                                  *
 *                                                                        *
 *  Copyright (c) 1999-2014, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

#include "triangulation/nboundarycomponent.h"

namespace regina {

void NBoundaryComponent::writeTextLong(std::ostream& out) const {
    writeTextShort(out);
    out << std::endl;

    if (isIdeal()) {
        NVertex* v = vertices_.front();
        out << "Vertex: " << v->markedIndex() << std::endl;
        out << "Appears as:" << std::endl;
        std::vector<NVertexEmbedding>::const_iterator it;
        for (it = v->getEmbeddings().begin(); it != v->getEmbeddings().end();
                ++it)
            out << "  " << it->getTetrahedron()->markedIndex()
                << " (" << it->getVertex() << ')' << std::endl;
    } else {
        out << "Triangles:" << std::endl;
        std::vector<NTriangle*>::const_iterator it;
        for (it = triangles_.begin(); it != triangles_.end(); ++it) {
            const NTriangleEmbedding& emb((*it)->getEmbedding(0));
            out << "  " << emb.getTetrahedron()->markedIndex() << " ("
                << emb.getVertices().trunc3() << ')' << std::endl;
        }
    }
}

} // namespace regina
